# Prerequisites

## Package Manager: uv

Serena is managed by `uv`.
If you do not have it yet, install it following the instructions [here](https://docs.astral.sh/uv/getting-started/installation/).

## Language-Specific Requirements

Depending on the programming language you intend to use with Serena, you may need to install additional tools or SDKs if you 
intend to use the language server backend of Serena.  
See the [language support documentation](../01-about/020_programming-languages) for details. 
